package de.mcs.tools.sps.mnemonic;

import static org.junit.jupiter.api.Assertions.assertEquals;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import de.mcs.tools.sps.exceptions.IllegalArgument;
import de.mcs.tools.sps.exceptions.SyntaxError;

class TestPORT {

  private final String MNEMONIC = "PORT";

  @Test
  void testNOP() throws SyntaxError {
    PORT port = new PORT(MNEMONIC + " 0x00");
    port.checkArgument();
    assertEquals(0x10, port.getByte());

    port = new PORT(MNEMONIC + " 0x01");
    port.checkArgument();
    assertEquals(0x11, port.getByte());

    port = new PORT(MNEMONIC + " 0x0f");
    port.checkArgument();
    assertEquals(0x1f, port.getByte());

    Assertions.assertThrows(SyntaxError.class, () -> {
      PORT port1 = new PORT(MNEMONIC);
      port1.checkArgument();
    });

    Assertions.assertThrows(IllegalArgument.class, () -> {
      PORT port1 = new PORT(MNEMONIC + " 0x10");
      port1.checkArgument();
    });
  }

  @Test
  void testNOPFactory() throws SyntaxError {
    Mnemonic mnemonic = MnemonicFactory.getMnemonic(MNEMONIC + " 0x00", 0);
    assertEquals(PORT.class, mnemonic.getClass());

    Assertions.assertThrows(SyntaxError.class, () -> {
      MnemonicFactory.getMnemonic(MNEMONIC, 0);
    });

    mnemonic = MnemonicFactory.getMnemonic(MNEMONIC + " 0x02", 0);
    assertEquals(0x12, mnemonic.getByte());

    mnemonic = MnemonicFactory.getMnemonic(MNEMONIC + " 12", 0);
    assertEquals(0x1C, mnemonic.getByte());

    mnemonic = MnemonicFactory.getMnemonic(MNEMONIC + " 0b00001010", 0);
    assertEquals(0x1A, mnemonic.getByte());

  }
}
